@@ -12,6 +12,9 @@ from advifswlib.interfaces.Abstract import InterfaceState, AbstractInterface
 from advpowcommon.util.execn import *
 
 class BTInterface(AbstractInterface):
+
+  name = 'Bluetooth'
+
   def pre_init(self):
     self.interfaces = {'BlueZAdapter': ['org.bluez',
                                         get_shell_command_output('dbus-send --system --dest=org.bluez --print-reply / org.bluez.Manager.DefaultAdapter | tail -1 | sed \'s/^.*"\\(.*\\)".*$/\\1/\' 2>/dev/null').replace('\n', ''),
@@ -23,15 +26,14 @@ class BTInterface(AbstractInterface):
                                         'org.bluez.Device',
                                         None,
                                         True]}
-    self.state = {'name': 'Bluetooth',
-                  'dbus': {'on': {'name': 'PropertyChanged',
-                                  'iface': self.interfaces['BlueZAdapter'][2],
-                                  'path': self.interfaces['BlueZAdapter'][1],
-                                  'args': {}},
-                           'connected': {'name': 'PropertyChanged',
-                                         'iface': self.interfaces['BlueZDevice'][2],
+    self.state = {'name': self.name,
+                  'dbus': {'on': {'signal_name': 'PropertyChanged',
+                                  'dbus_interface': self.interfaces['BlueZAdapter'][2],
+                                  'path': self.interfaces['BlueZAdapter'][1]},
+                           'connected': {'signal_name': 'PropertyChanged',
+                                         'dbus_interface': self.interfaces['BlueZDevice'][2],
                                          'path': self.interfaces['BlueZDevice'][1],
-                                         'args': {'path_keyword': 'path'}}
+                                         'path_keyword': 'path'}
                           },
                   'images': ('ifsw_statusarea_bluetooth_off', 
                              'ifsw_statusarea_bluetooth_on', 
@@ -104,8 +106,10 @@ class BTInterface(AbstractInterface):
   def run_commands(self, flag):
     self.get_interface('BlueZAdapter').SetProperty('Powered', flag)
     self.switched()
+    return False
 
   def run_mode_commands(self, visible):
     self.get_interface('BlueZAdapter').SetProperty('Discoverable', 
                                                    bool(visible))
     self.switched()
+    return False
